# -*- coding: utf-8 -*-
"""
Created on Wed Nov 29 22:45:29 2017

@author: bert_

https://www.pyimagesearch.com/2014/09/15/python-compare-two-images/
"""

# import the necessary packages
from skimage.measure import compare_ssim as ssim
import matplotlib.pyplot as plt
import numpy as np
import cv2

def mse(imageA, imageB):
	# the 'Mean Squared Error' between the two images is the
	# sum of the squared difference between the two images;
	# NOTE: the two images must have the same dimension
	err = np.sum((imageA.astype("float") - imageB.astype("float")) ** 2)
	err /= float(imageA.shape[0] * imageA.shape[1])
	
	# return the MSE, the lower the error, the more "similar"
	# the two images are
	return err
 
def compare_images(imageA, imageB, title):
	# compute the mean squared error and structural similarity
	# index for the images
	m = mse(imageA, imageB)
	s = ssim(imageA, imageB)
 
	# setup the figure
	fig = plt.figure(title)
	plt.suptitle("MSE: %.2f, SSIM: %.2f" % (m, s))
 
	# show first image
	ax = fig.add_subplot(1, 2, 1)
	plt.imshow(imageA, cmap = plt.cm.gray)
	plt.axis("off")
 
	# show the second image
	ax = fig.add_subplot(1, 2, 2)
	plt.imshow(imageB, cmap = plt.cm.gray)
	plt.axis("off")
 
	# show the images
	plt.show()
    

portrait = cv2.imread("img/bottom-adjusted-old.png")
detail = cv2.imread("img/bottom-adjusted-new.png")
# gausian blur 2px
control = cv2.imread("img/bottom-adjusted-cnt.png")
 
# convert the images to grayscale
detail = cv2.cvtColor(detail, cv2.COLOR_BGR2GRAY)
portrait = cv2.cvtColor(portrait, cv2.COLOR_BGR2GRAY)
control = cv2.cvtColor(control, cv2.COLOR_BGR2GRAY)

# initialize the figure
fig = plt.figure("Images")
images = ("Portrait", portrait), ("Detail", detail), ("Control Image", control)
 
# loop over the images
for (i, (name, image)) in enumerate(images):
	# show the image
	ax = fig.add_subplot(1, 3, i + 1)
	ax.set_title(name)
	plt.imshow(image, cmap = plt.cm.gray)
	plt.axis("off")
 
# show the figure
plt.show()
 
# compare the images
compare_images(portrait, portrait, "Portrait vs. Portrait")
compare_images(portrait, detail, "Portrait vs. Detail")
compare_images(portrait, control, "Control Image")